########################### Adv Long Example 4b using R #########################

# Set width of output and number of significant digits printed,
# number of digits before using scientific notation, shut off significance stars
options(width=120, digits=8, scipen=9, show.signif.stars=FALSE)

#####  Check to see if packages are downloaded, install if not, then load  #####

if (!require("readxl")) install.packages("readxl")
library(readxl) # To import xls or xlsx data as table

if (!require("expss")) install.packages("expss")
library(expss) # To add variable and value labels, sort

if (!require("lme4")) install.packages("lme4")
library(lme4) # To estimate MLMs using lmer

if (!require("lmerTest")) install.packages("lmerTest")
library(lmerTest) # To get Satterthwaite DDF in lmer

if (!require("performance")) install.packages("performance")
library(performance) # To get ICC in lmer

if (!require("TeachingDemos")) install.packages("TeachingDemos")
library(TeachingDemos) # To create text output files


################################################################################
#####             BEGIN DATA MANIPULATION OF EXAMPLE 4b                    #####
#####              CHANGE "filesave" TO YOUR DIRECTORY                     #####
################################################################################

# Define variables for working directory and data name -- CHANGE THESE
filesave = "C:\\Dropbox/23_PSQF7375_AdvLong/PSQF7375_AdvLong_Example4b/"
filename = "AdvLong_Example4b.xlsx"
setwd(dir=filesave)

# Import Example4b stacked data from excel in sheet "Data"
Example4b = read_excel(paste0(filesave,filename), sheet="Data") 
# Convert to data frame to use in analysis
Example4b = as.data.frame(Example4b)
# Sort data by PersonID
Example4b = sort_asc(Example4b,PersonID)

# Open output text file
txtStart(file=paste0(filesave,"AdvLong_Example4b_R_Output.txt"))


################################################################################
#####           BEGIN MULTILEVEL MODELS FOR EXAMPLE 4b STACKED DATA        #####
################################################################################


print("Step 1: X Stressors Predicting Symptoms Y")
Step1 = lmer(data=Example4b, REML=FALSE, 
             formula=symptoms~1+women+age80+stressor+PMstress40+women:age80+(1|PersonID))
print("Show results using Satterthwaite DDF") 
summary(Step1, ddf="Satterthwaite")
print("BP X to Y Effect"); contest1D(Step1, ddf="Satterthwaite", L=c(0,0,0,1,1,0)) 

txtComment(" ") # insert blank space in output


print("Step 2ish: M Mood Predicting Symptoms Y")
Step2 = lmer(data=Example4b, REML=FALSE, 
             formula=symptoms~1+women+age80+mood2+PMmood2+women:age80+(1|PersonID))
print("Show results using Satterthwaite DDF") 
summary(Step2, ddf="Satterthwaite")
print("BP M to Y Effect"); contest1D(Step2, ddf="Satterthwaite", L=c(0,0,0,1,1,0)) 


txtComment(" ") # insert blank space in output


# Close output text file
txtStop()
